/* SPDX-License-Identifier: GPL-2.0 */
#ifndef _RUPSCHED_VDEVPRINTF_H
#define _RUPSCHED_VDEVPRINTF_H

#include <linux/cdev.h>
#include <asm/rodata.h>

void vdevprintf(char __rodata *fmt, struct ocdev *dev, va_list args);

#endif /* _RUPSCHED_VDEVPRINTF_H */